@@ -15,27 +15,43 @@
 """
 __docformat__ = 'restructuredtext'
 
-try:
-    from collections import abc
-except ImportError:  # pragma: PY2
-    # Python 2
-    import collections as abc
-
-from datetime import datetime
-from datetime import date
-from datetime import timedelta
-from datetime import time
 import re
-
+from collections import abc
+from datetime import date
+from datetime import datetime
+from datetime import time
+from datetime import timedelta
 
 from zope.interface import classImplements
 from zope.interface import classImplementsFirst
-from zope.interface import implementer
 from zope.interface import implementedBy
+from zope.interface import implementer
 from zope.interface.interfaces import IInterface
 
-
+from zope.schema._bootstrapfields import Bool
+from zope.schema._bootstrapfields import Complex
+from zope.schema._bootstrapfields import Container  # API import for __init__
+from zope.schema._bootstrapfields import Decimal
+from zope.schema._bootstrapfields import Field
+from zope.schema._bootstrapfields import Int
+from zope.schema._bootstrapfields import Integral
+from zope.schema._bootstrapfields import \
+    InvalidDecimalLiteral  # noqa: reexport
+from zope.schema._bootstrapfields import Iterable
+from zope.schema._bootstrapfields import MinMaxLen
+from zope.schema._bootstrapfields import Number
+from zope.schema._bootstrapfields import Object
+from zope.schema._bootstrapfields import Orderable
+from zope.schema._bootstrapfields import Password
+from zope.schema._bootstrapfields import Rational
+from zope.schema._bootstrapfields import Real
+from zope.schema._bootstrapfields import Text
+from zope.schema._bootstrapfields import TextLine
+from zope.schema._bootstrapfields import _NotGiven
+from zope.schema.fieldproperty import FieldProperty
 from zope.schema.interfaces import IASCII
+from zope.schema.interfaces import IURI
+from zope.schema.interfaces import ConstraintNotSatisfied
 from zope.schema.interfaces import IASCIILine
 from zope.schema.interfaces import IBaseVocabulary
 from zope.schema.interfaces import IBool
@@ -57,25 +73,29 @@ from zope.schema.interfaces import IFromBytes
 from zope.schema.interfaces import IFromUnicode
 from zope.schema.interfaces import IFrozenSet
 from zope.schema.interfaces import IId
-from zope.schema.interfaces import IIterable
 from zope.schema.interfaces import IInt
 from zope.schema.interfaces import IIntegral
 from zope.schema.interfaces import IInterfaceField
+from zope.schema.interfaces import IIterable
 from zope.schema.interfaces import IList
-from zope.schema.interfaces import IMinMaxLen
 from zope.schema.interfaces import IMapping
+from zope.schema.interfaces import IMinMaxLen
 from zope.schema.interfaces import IMutableMapping
 from zope.schema.interfaces import IMutableSequence
 from zope.schema.interfaces import INativeString
 from zope.schema.interfaces import INativeStringLine
-from zope.schema.interfaces import IObject
 from zope.schema.interfaces import INumber
+from zope.schema.interfaces import InvalidDottedName
+from zope.schema.interfaces import InvalidId
+from zope.schema.interfaces import InvalidURI
+from zope.schema.interfaces import InvalidValue
+from zope.schema.interfaces import IObject
 from zope.schema.interfaces import IPassword
 from zope.schema.interfaces import IPythonIdentifier
-from zope.schema.interfaces import IReal
 from zope.schema.interfaces import IRational
-from zope.schema.interfaces import ISet
+from zope.schema.interfaces import IReal
 from zope.schema.interfaces import ISequence
+from zope.schema.interfaces import ISet
 from zope.schema.interfaces import ISource
 from zope.schema.interfaces import ISourceText
 from zope.schema.interfaces import IText
@@ -83,49 +103,15 @@ from zope.schema.interfaces import ITextLine
 from zope.schema.interfaces import ITime
 from zope.schema.interfaces import ITimedelta
 from zope.schema.interfaces import ITuple
-from zope.schema.interfaces import IURI
-
-from zope.schema.interfaces import ValidationError
-from zope.schema.interfaces import InvalidValue
-from zope.schema.interfaces import WrongType
-from zope.schema.interfaces import WrongContainedType
-from zope.schema.interfaces import NotUnique
 from zope.schema.interfaces import NotAnInterface
-from zope.schema.interfaces import InvalidURI
-from zope.schema.interfaces import InvalidId
-from zope.schema.interfaces import InvalidDottedName
-from zope.schema.interfaces import ConstraintNotSatisfied
-
-from zope.schema._bootstrapfields import Field
-from zope.schema._bootstrapfields import Complex
-from zope.schema._bootstrapfields import Container  # API import for __init__
-from zope.schema._bootstrapfields import Iterable
-from zope.schema._bootstrapfields import Orderable
-from zope.schema._bootstrapfields import Text
-from zope.schema._bootstrapfields import TextLine
-from zope.schema._bootstrapfields import Bool
-from zope.schema._bootstrapfields import Int
-from zope.schema._bootstrapfields import Integral
-from zope.schema._bootstrapfields import Number
-from zope.schema._bootstrapfields import InvalidDecimalLiteral  # noqa: reexport
-from zope.schema._bootstrapfields import Decimal
-from zope.schema._bootstrapfields import Password
-from zope.schema._bootstrapfields import Rational
-from zope.schema._bootstrapfields import Real
-from zope.schema._bootstrapfields import MinMaxLen
-from zope.schema._bootstrapfields import _NotGiven
-from zope.schema._bootstrapfields import Object
-from zope.schema.fieldproperty import FieldProperty
-from zope.schema.vocabulary import getVocabularyRegistry
+from zope.schema.interfaces import NotUnique
+from zope.schema.interfaces import ValidationError
+from zope.schema.interfaces import WrongContainedType
+from zope.schema.interfaces import WrongType
 from zope.schema.vocabulary import SimpleVocabulary
+from zope.schema.vocabulary import getVocabularyRegistry
 
 
-from zope.schema._compat import text_type
-from zope.schema._compat import string_types
-from zope.schema._compat import binary_type
-from zope.schema._compat import PY3
-from zope.schema._compat import make_binary
-
 # Fix up bootstrap field types
 Field.title = FieldProperty(IField['title'])
 Field.description = FieldProperty(IField['description'])
@@ -178,19 +164,18 @@ class implementer_if_needed(object):
 @implementer(ISourceText)
 class SourceText(Text):
     __doc__ = ISourceText.__doc__
-    _type = text_type
+    _type = str
 
 
 @implementer(IBytes, IFromUnicode, IFromBytes)
 class Bytes(MinMaxLen, Field):
     __doc__ = IBytes.__doc__
-
-    _type = binary_type
+    _type = bytes
 
     def fromUnicode(self, value):
         """ See IFromUnicode.
         """
-        return self.fromBytes(make_binary(value))
+        return self.fromBytes(value.encode('ascii'))
 
     def fromBytes(self, value):
         self.validate(value)
@@ -198,7 +183,7 @@ class Bytes(MinMaxLen, Field):
 
 
 @implementer_if_needed(INativeString, IFromUnicode, IFromBytes)
-class NativeString(Text if PY3 else Bytes):
+class NativeString(Text):
     """
     A native string is always the type `str`.
 
@@ -212,11 +197,10 @@ class NativeString(Text if PY3 else Bytes):
     """
     _type = str
 
-    if PY3:  # pragma: no branch
-        def fromBytes(self, value):
-            value = value.decode('utf-8')
-            self.validate(value)
-            return value
+    def fromBytes(self, value):
+        value = value.decode('utf-8')
+        self.validate(value)
+        return value
 
 
 @implementer(IASCII)
@@ -241,7 +225,7 @@ class BytesLine(Bytes):
 
 
 @implementer_if_needed(INativeStringLine, IFromUnicode, IFromBytes)
-class NativeStringLine(TextLine if PY3 else BytesLine):
+class NativeStringLine(TextLine):
     """
     A native string is always the type `str`; this field excludes
     newlines.
@@ -256,11 +240,10 @@ class NativeStringLine(TextLine if PY3 else BytesLine):
     """
     _type = str
 
-    if PY3:  # pragma: no branch
-        def fromBytes(self, value):
-            value = value.decode('utf-8')
-            self.validate(value)
-            return value
+    def fromBytes(self, value):
+        value = value.decode('utf-8')
+        self.validate(value)
+        return value
 
 
 @implementer(IASCIILine)
@@ -302,7 +285,7 @@ class Float(Real):
         Traceback (most recent call last):
         ...
         InvalidFloatLiteral: invalid literal for float(): 1/2
-        >>> f.fromUnicode(str(2**31234) + '.' + str(2**256))
+        >>> f.fromUnicode(str(2**11234) + '.' + str(2**256))
         ... # doctest: +ELLIPSIS
         inf
         >>> f.fromUnicode("not a number") # doctest: +IGNORE_EXCEPTION_DETAIL
@@ -326,7 +309,7 @@ class Float(Real):
         Traceback (most recent call last):
         ...
         InvalidFloatLiteral: invalid literal for float(): 1/2
-        >>> f.fromBytes((str(2**31234) + '.' + str(2**256)).encode('ascii'))
+        >>> f.fromBytes((str(2**11234) + '.' + str(2**256)).encode('ascii'))
         ... # doctest: +ELLIPSIS
         inf
         >>> f.fromBytes(b"not a number") # doctest: +IGNORE_EXCEPTION_DETAIL
@@ -401,7 +384,7 @@ class Choice(Field):
     def __init__(self, values=None, vocabulary=None, source=None, **kw):
         """Initialize object."""
         if vocabulary is not None:
-            if (not isinstance(vocabulary, string_types)
+            if (not isinstance(vocabulary, str)
                     and not IBaseVocabulary.providedBy(vocabulary)):
                 raise ValueError('vocabulary must be a string or implement '
                                  'IBaseVocabulary')
@@ -424,7 +407,7 @@ class Choice(Field):
         self.vocabularyName = None
         if values is not None:
             self.vocabulary = SimpleVocabulary.fromValues(values)
-        elif isinstance(vocabulary, string_types):
+        elif isinstance(vocabulary, str):
             self.vocabularyName = vocabulary
         else:
             if (not ISource.providedBy(vocabulary)
@@ -504,17 +487,15 @@ class _StrippedNativeStringLine(NativeStringLine):
 
     def fromUnicode(self, value):
         v = value.strip()
-        # On Python 2, self._type is bytes, so we need to encode
-        # unicode down to ASCII bytes. On Python 3, self._type is
-        # unicode, but we don't want to allow non-ASCII values, to match
-        # Python 2 (our regexs would reject that anyway.)
+        # self._type is unicode, but we don't want to allow non-ASCII
+        # values, to match the old behaviour on Python 2 (our regexes would
+        # reject that anyway).
         try:
             v = v.encode('ascii')  # bytes
         except UnicodeEncodeError:
             raise self._invalid_exc_type(value).with_field_and_value(
                 self, value)
-        if not isinstance(v, self._type):  # pragma: no branch
-            v = v.decode('ascii')
+        v = v.decode('ascii')
         self.validate(v)
         return v
 
