@@ -15,8 +15,10 @@
 """
 import unittest
 
+
 # pylint:disable=inherit-non-class
 
+
 class FieldReadAccessorTests(unittest.TestCase):
 
     def _getTargetClass(self):
@@ -40,6 +42,7 @@ class FieldReadAccessorTests(unittest.TestCase):
 
     def test_ctor_created_inside_interface(self):
         from zope.interface import Interface
+
         from zope.schema import Text
 
         field = Text(title=u'Hmm')
@@ -62,6 +65,7 @@ class FieldReadAccessorTests(unittest.TestCase):
         from zope.interface import providedBy
         from zope.interface.interfaces import IAttribute
         from zope.interface.interfaces import IMethod
+
         from zope.schema import Text
 
         # When wrapping a field that provides stuff,
@@ -85,7 +89,7 @@ class FieldReadAccessorTests(unittest.TestCase):
         attr = 'STRICT_IRO'
         try:
             getattr(ro.C3, attr)
-        except AttributeError:
+        except AttributeError:  # pragma: no cover
             # https://github.com/zopefoundation/zope.interface/issues/194
             # zope.interface 5.0.0 used this incorrect spelling.
             attr = 'STRICT_RO'
@@ -169,6 +173,7 @@ class FieldReadAccessorTests(unittest.TestCase):
 
     def test_set_readonly(self):
         from zope.interface import Interface
+
         from zope.schema import Text
         field = Text(readonly=True)
 
@@ -207,7 +212,9 @@ class FieldReadAccessorTests(unittest.TestCase):
             pass
 
         writer = Writer()
-        writer.__name__ = 'setMe' # pylint:disable=attribute-defined-outside-init
+        # pylint:disable=attribute-defined-outside-init
+        writer.__name__ = 'setMe'
+        # pylint:enable=attribute-defined-outside-init
         getter.writer = writer
 
         class Foo(object):
@@ -254,6 +261,7 @@ class FieldWriteAccessorTests(unittest.TestCase):
 
     def test_ctor_created_inside_interface(self):
         from zope.interface import Interface
+
         from zope.schema import Text
 
         field = Text(title=u'Hmm')
@@ -287,6 +295,7 @@ class Test_accessors(unittest.TestCase):
 
     def test_w_only_read_accessor(self):
         from zope.interface import Interface
+
         from zope.schema import Text
 
         field = Text(title=u'Hmm', readonly=True)
@@ -307,6 +316,7 @@ class Test_accessors(unittest.TestCase):
 
     def test_w_read_and_write_accessors(self):
         from zope.interface import Interface
+
         from zope.schema import Text
 
         field = Text(title=u'Hmm')
